from setuptools import setup, find_packages
import pathlib

here = pathlib.Path(__file__).parent
long_description = (here / "README.md").read_text(encoding="utf-8")

setup(
    name="zspdu",
    version="0.0.1",  # bump version before re-upload
    description="Control ZSPDU smart power distribution unit via serial port",
    long_description=long_description,
    long_description_content_type="text/markdown",  # tells PyPI to render Markdown
    author="Ganesan Selvaraj",
    author_email="ganesanluna@yahoo.in",
    url="https://github.com/ganesanluna/zspdu",
    license="MIT",
    packages=find_packages(where="src"),
    package_dir={"": "src"},
    install_requires=[
        "pyserial",
        "pydantic",
        "robotframework"
    ],
    entry_points={
        "console_scripts": [
            "zspdu=zspdu.cli:main",
        ],
    },
    classifiers=[
        "Programming Language :: Python :: 3",
        "Operating System :: OS Independent",
    ],
    python_requires=">=3.8",
)
